\name{gahgu95c_dbconn}

\alias{gahgu95c_dbconn}
\alias{gahgu95c_dbfile}
\alias{gahgu95c_dbschema}
\alias{gahgu95c_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  gahgu95c_dbconn()
  gahgu95c_dbfile()
  gahgu95c_dbschema(file="", show.indices=FALSE)
  gahgu95c_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{gahgu95c_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{gahgu95c_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{gahgu95c_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{gahgu95c_dbschema} prints the schema definition of the
  package annotation DB.

  \code{gahgu95c_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{gahgu95c_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{gahgu95c_dbfile}: a character string with the path to the
  package annotation DB.

  \code{gahgu95c_dbschema}: none (invisible \code{NULL}).

  \code{gahgu95c_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(gahgu95c_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by gahgu95c_dbconn() was created with:
  dbConnect(SQLite(), dbname=gahgu95c_dbfile(), cache_size=64000, synchronous=0)

  gahgu95c_dbschema()

  gahgu95c_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

